local media = LibStub("LibSharedMedia-3.0")

function PWBAuraBar:BuildGui()

	AuraFrame = CreateFrame("Frame", nil, UIParent)
	AuraFrame:SetFrameStrata("BACKGROUND")
	AuraFrame:SetBackdrop({bgFile = media:Fetch("background", "Blizzard Tooltip"), tile = false})
	AuraFrame:SetPoint("BOTTOMLEFT", self.db.x, self.db.y)

	-- Shield frame movement
	AuraFrame:RegisterForDrag('LeftButton')
	AuraFrame:SetClampedToScreen(true)
	AuraFrame:SetScript("OnDragStart", function(self) PWBAuraBar:Dragstart(self) end )
	AuraFrame:SetScript('OnDragStop', function(self) PWBAuraBar:Dragstop(self) end )

	for i = 1, self.db.barcount do
		self.auraBars[i] = PWBAuraBar:Create()
	end

	PWBAuraBar:UpdateStyling()
	PWBAuraBar:UpdateVisiblity()
end

function PWBAuraBar:Create()
	frame = CreateFrame("StatusBar", nil, AuraFrame)
	frame:SetMinMaxValues(0, 100)
	frame:SetValue(10)

	return frame
end


function PWBAuraBar:UpdateStyling()
	local style = nil

	if self.db.useDefaults then
		style = Protwarbar.db.profile.default.appearence
	else
		style = self.db
	end

	local scale = Protwarbar.db.profile.default.appearence.scale

	AuraFrame:SetWidth(self.db.width * scale)
	AuraFrame:SetHeight(self.db.height * self.db.barcount * scale)
	AuraFrame:SetMovable(not Protwarbar.db.profile.locked)
	AuraFrame:EnableMouse(not Protwarbar.db.profile.locked)
	AuraFrame:SetPoint("BOTTOMLEFT", self.db.x, self.db.y)

	for i = 1, self.db.barcount do
		self.auraBars[i]:SetStatusBarTexture(media:Fetch("statusbar", style.barTexture))
		self.auraBars[i]:SetOrientation(style.orientation)
		self.auraBars[i]:SetReverseFill(style.reverse)
		self.auraBars[i]:SetWidth(self.db.width * scale)
		self.auraBars[i]:SetHeight(self.db.height * scale)
		self.auraBars[i]:SetPoint("BOTTOMLEFT", 0, (i - 1) * self.db.height * scale)
	end

	if Protwarbar.db.profile.locked then
		AuraFrame:SetBackdropColor(style.background[1], style.background[2],style.background[3], style.background[4])
	else
		AuraFrame:SetBackdropColor(Protwarbar.db.profile.default.appearence.unlockbg[1],
			Protwarbar.db.profile.default.appearence.unlockbg[2],
			Protwarbar.db.profile.default.appearence.unlockbg[3],
			Protwarbar.db.profile.default.appearence.unlockbg[4])
	end

end

function PWBAuraBar:UpdateVisiblity()
	if self.db.enabled and Protwarbar:IsVisible() then
		AuraFrame:Show()
	else
		AuraFrame:Hide()
	end
end

function PWBAuraBar:Dragstart(frame)
	if not Protwarbar.db.locked then
		frame:StartMoving()
	end
end

function PWBAuraBar:Dragstop(frame)
	frame:StopMovingOrSizing()

	self.db.x = AuraFrame:GetLeft()
	self.db.y = AuraFrame:GetBottom()
end