local L = LibStub("AceLocale-3.0"):GetLocale("Protwarbar")

function PWBShieldbar:OnInitialize()
	self.db = Protwarbar.db.profile.PWBShieldbar

	self.shieldCount = 0
	self.shieldList = {}
	self.enabledShieldList = {}
	self.shieldTable = {}

	PWBShieldbar:BuildGui()

	self:RegisterMessage("PWB_ABILITIES_LOADED")
	self:RegisterMessage("PWB_PROFILE_CHANGED")
	self:RegisterMessage("PWB_REFRESH_CONFIG")
	self:RegisterMessage("PWB_UPDATE_VISIBILITY")
	self:RegisterMessage("PWB_UPDATE_HANDLERS")
end

function PWBShieldbar:OnEnable()
	self.playerName = UnitName("player")
	Protwarbar:Print(playerName)
	PWBShieldbar:PWB_UPDATE_HANDLERS()
end

function PWBShieldbar:PWB_UPDATE_HANDLERS()
	self:CancelAllTimers()
	self:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED")

	if self.db.enabled and Protwarbar.db.profile.enabled then
		self:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
		self:ScheduleRepeatingTimer("QuickTimer", 0.1)
	end
end

function PWBShieldbar:PWB_PROFILE_CHANGED()
	self.db = Protwarbar.db.profile.PWBShieldbar
end

function PWBShieldbar:PWB_ABILITIES_LOADED(event, abilities)

	for id, ability in pairs(abilities) do
		if ability.shield == true then

			ability.name = GetSpellInfo(id)
			table.insert(self.shieldList, id, ability)

			self:AddShield(ability, id)
		end
	end

	LibStub("AceConfig-3.0"):RegisterOptionsTable("PWBShieldbar", PWBShieldbar:CreateOptions());
	AceConfig:AddToBlizOptions("PWBShieldbar", L["Shieldbar"], "Protwarbar");
end

function PWBShieldbar:PWB_REFRESH_CONFIG()
	PWBShieldbar:RefreshConfig()
end

function PWBShieldbar:PWB_UPDATE_VISIBILITY()
	PWBShieldbar:UpdateVisiblity()
end

function PWBShieldbar:COMBAT_LOG_EVENT_UNFILTERED(event, _, eventType, _, _, _, _, _, _, destName, _, _, spellId, _, _, _, amount)
	if (self.playerName == destName) then
		if (eventType == "SPELL_AURA_APPLIED") then
			PWBShieldbar:Update(spellId, amount)
			return
		end

		if (eventType == "SPELL_AURA_REFRESH") then
			PWBShieldbar:Update(spellId, amount)
			return
		end

		if (eventType == "SPELL_AURA_REMOVED") then
			PWBShieldbar:Update(spellId, 0)
			return
		end
	end
end

function PWBShieldbar:RefreshConfig()
	self.enabledShieldList = {}
	self.shieldTable = {}

	for id, ability in pairs(self.shieldList) do
		PWBShieldbar:AddShield(ability, id)
	end

	PWBShieldbar:UpdateStyling()
	PWBShieldbar:UpdateVisiblity()
end

function PWBShieldbar:AddShield(ability, id)
	if self.db.shields[id] == nil then
		self.db.shields[id] = {}
		self.db.shields[id].enabled = false
	end

	if self.db.shields[id].enabled then
		table.insert(self.enabledShieldList, id, id)
		table.insert(self.shieldTable, id, {0, 0})
	end
end

function PWBShieldbar:Update(id, value)
	if (self.enabledShieldList[id] ~= nil) then
		self.shieldTable[id] = {value, value}
	end
end

function PWBShieldbar:QuickTimer()
	local shieldValue = 0
	local shieldTotal = 0

	local n, spellId, value

	for id, shield in pairs(self.shieldTable) do
		if shield[1] > 0 then
			n,_,_,_,_,_,_,_,_,_,spellId,_,_,_,value,_ = UnitAura("player", self.shieldList[id].name, nil, "HELPFUL")

			if n then
				shieldTotal = shieldTotal + shield[1]
				shieldValue = shieldValue + value or 0
			end
		end
	end

	ShieldBarText:SetText(string.format("%.1fK", shieldValue / 1000))
	if (shieldTotal > 0) then
		ShieldBar:SetValue(shieldValue / shieldTotal * 100)
	else
		ShieldBar:SetValue(0)
	end
end

